@@ -10,15 +10,22 @@ class DCCAE(_DCCA_base):
     """
     A class used to fit a DCCAE model.
 
-    Examples
-    --------
-    >>> from cca_zoo.deepmodels import DCCAE
-    >>> model = DCCAE()
+    :Citation:
+
+    Wang, Weiran, et al. "On deep multi-view representation learning." International conference on machine learning. PMLR, 2015.
+
     """
 
-    def __init__(self, latent_dims: int, objective=objectives.MCCA,
-                 encoders=None,
-                 decoders=None, r: float = 0, eps: float = 1e-3, lam=0.5):
+    def __init__(
+        self,
+        latent_dims: int,
+        objective=objectives.MCCA,
+        encoders=None,
+        decoders=None,
+        r: float = 0,
+        eps: float = 1e-3,
+        lam=0.5,
+    ):
         """
         :param latent_dims: # latent dimensions
         :param objective: # CCA objective: normal tracenorm CCA by default
@@ -41,28 +48,39 @@ class DCCAE(_DCCA_base):
         self.objective = objective(latent_dims, r=r, eps=eps)
 
     def forward(self, *args):
-        z = self.encode(*args)
-        return z
-
-    def encode(self, *args):
         z = []
         for i, encoder in enumerate(self.encoders):
             z.append(encoder(args[i]))
-        return tuple(z)
+        return z
 
-    def decode(self, *args):
+    def recon(self, *args):
+        """
+        :param args:
+        :return:
+        """
+        z = self(*args)
+        return self._decode(*z)
+
+    def _decode(self, *z):
+        """
+        This method is used to decode from the latent space to the best prediction of the original views
+
+        """
         recon = []
         for i, decoder in enumerate(self.decoders):
-            recon.append(decoder(args[i]))
-        return tuple(recon)
+            recon.append(decoder(z[i]))
+        return recon
 
     def loss(self, *args):
-        z = self.encode(*args)
-        recon = self.decode(*z)
-        recon_loss = self.recon_loss(args[:len(recon)], recon)
+        z = self(*args)
+        recon = self._decode(*z)
+        recon_loss = self._recon_loss(args[: len(recon)], recon)
         return self.lam * recon_loss + self.objective.loss(*z)
 
     @staticmethod
-    def recon_loss(x, recon):
-        recons = [F.mse_loss(recon_, x_, reduction='mean') for recon_, x_ in zip(recon, x)]
+    def _recon_loss(x, recon):
+        recons = [
+            F.binary_cross_entropy(recon_, x_, reduction="mean")
+            for recon_, x_ in zip(recon, x)
+        ]
         return torch.stack(recons).sum(dim=0)
